# blitzer-language-pli

Pali language pack for blitzer-cli

## License

This package is licensed under CC BY-NC 4.0.

This plugin uses work from the Digital Pāḷi Dictionary Project, licensed under CC BY-NC 4.0.
See https://github.com/digitalpalidictionary/digitalpalidictionary

Copyright (C) 2025 Samiddhi

